%define url_ver		%(echo %{version} | cut -d. -f1,2)

%define enable_fts	0

%define api_version	2.0
%define gir_major       2.0
%define lib_major	0
%define lib_name        %mklibname %{name} %{api_version} %{lib_major}
%define libnamedev      %mklibname -d %{name} %{api_version}
%define gir_name        %mklibname %{name}-gir %{gir_major}

# Turn off the brp-python-bytecompile script
%define __brp_python_bytecompile %{nil}

Summary:	Event logging framework for the desktop
Name:		zeitgeist
Version:	1.0.3
Release:	%mkrel 1
License:	LGPLv3
Group:		System/Libraries
URL:		https://launchpad.net/zeitgeist
Source0:	https://launchpad.net/%{name}/%{url_ver}/%{version}/+download/%{name}-%{version}.tar.xz
BuildRequires:	pkgconfig(python3)
%if %{enable_fts}
BuildRequires:	xapian-devel
%endif
BuildRequires:	raptor2
BuildRequires:	python3-rdflib
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(json-glib-1.0)
BuildRequires:	pkgconfig(telepathy-glib)
BuildRequires:	vala-devel
Requires:	python3-dbus
Requires:	python3-pyxdg

%description
Zeitgeist is an "Event Logging Framework" that provides cross
application awareness of the desktop's activities.

You worked on a file, but you cannot remember where you saved it? You
visited a web page about basketball three days ago, but you cannot
find the URL in your browser's history? No problem, this is where
Zeitgeist enters the scene. It knows a lot about your activities and
has a feature rich D-Bus API which allows GUI applications like
gnome-zeitgeist, zeitgeistfs and others to present you your
activities in a readable way.

%package -n	%{lib_name}
Summary: 	Libraries for %{name}
Group:		System/Libraries

%description -n	%{lib_name}
This package contains the libraries for %{name}.

%package -n	%{gir_name}
Summary: 	GObject Introspection interface description for %{name}
Group:		System/Libraries
Requires:	%{lib_name} = %{version}-%{release}

%description -n	%{gir_name}
GObject Introspection interface description for %{name}.

%package -n	%{libnamedev}
Summary: 	Development libraries and header files of %{name}
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{lib_name} = %{version}-%{release}
Requires:	%{gir_name} = %{version}-%{release}

%description -n	%{libnamedev}
This package contains the header and pkg-config files for developing
with %{name}.

%prep
%setup -q
%autopatch -p1

%build
export PYTHON=%{__python3}

%configure \
%if %{enable_fts}
	--enable-fts \
%endif
	--disable-rpath
%make_build

%install
%make_install

# handle docs in files section
rm -rf %{buildroot}%{_docdir}

# fix systemd unit file
%if %{enable_fts}
sed -i -e 's,@libexecdir@,%{_libexecdir},g' %{buildroot}%{_userunitdir}/%{name}-fts.service
%endif

# remove unpackaged files
find %{buildroot} -name '*.la' -delete

%files
%doc AUTHORS NEWS
%{_bindir}/%{name}-daemon
%{_bindir}/%{name}-datahub
%{_datadir}/%{name}/
%{_datadir}/dbus-1/services/org.gnome.zeitgeist.Engine.service
%{_userunitdir}/zeitgeist.service
%{_mandir}/man1/%{name}-daemon.1*
%{_mandir}/man1/%{name}-datahub.1*
%{python3_sitelib}/%{name}/
%{_sysconfdir}/xdg/autostart/%{name}-datahub.desktop
%{_datadir}/bash-completion/completions/%{name}-daemon
#Zeitgeist full-text search (fts) indexer
%if %{enable_fts}
%{_userunitdir}/%{name}-fts.service
%dir %{_libexecdir}/%{name}/
%{_libexecdir}/%{name}/%{name}-fts
%{_datadir}/dbus-1/services/org.gnome.zeitgeist.SimpleIndexer.service
%endif

%files -n %{lib_name}
%{_libdir}/lib%{name}-%{api_version}.so.%{lib_major}
%{_libdir}/lib%{name}-%{api_version}.so.%{lib_major}.*

%files -n %{gir_name}
%{_libdir}/girepository-1.0/*-%{gir_major}.typelib

%files -n %{libnamedev}
%dir %{_includedir}/%{name}-%{api_version}
%{_includedir}/%{name}-%{api_version}/*.h
%{_libdir}/lib%{name}-%{api_version}.so
%{_libdir}/pkgconfig/%{name}-%{api_version}.pc
%{_datadir}/gir-1.0/*-%{gir_major}.gir
%{_datadir}/vala/vapi/*.vapi
%{_datadir}/vala/vapi/*.deps


%changelog
* Thu Oct 22 2020 daviddavid <daviddavid> 1.0.3-1.mga8
+ Revision: 1638292
- new version: 1.0.3

* Sun Feb 16 2020 umeabot <umeabot> 1.0.2-4.mga8
+ Revision: 1533892
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Sep 25 2019 daviddavid <daviddavid> 1.0.2-3.mga8
+ Revision: 1445749
- rebuild for python3.8

* Mon Sep 02 2019 daviddavid <daviddavid> 1.0.2-2.mga8
+ Revision: 1436329
- port to Python 3

* Mon Mar 11 2019 wally <wally> 1.0.2-1.mga7
+ Revision: 1374122
- new version 1.0.2

* Wed Jan 02 2019 kekepower <kekepower> 1.0.1-1.mga7
+ Revision: 1348560
- Update to version 1.0.1

* Sun Sep 23 2018 umeabot <umeabot> 2.mga7-current
+ Revision: 1302044
- Mageia 7 Mass Rebuild

* Mon May 29 2017 luigiwalser <luigiwalser> 1.0-1.mga6
+ Revision: 1105478
- more spec cleanups from wally
- 1.0
- update URLs
- clean spec

* Wed Feb 17 2016 umeabot <umeabot> 0.9.16-2.mga6
+ Revision: 963681
- Mageia 6 Mass Rebuild

* Fri Aug 28 2015 ycantin <ycantin> 0.9.16-1.mga6
+ Revision: 870360
- new version 0.9.16
- remove old patchs
- fix compilation (Empty %%files zeitgeist.lang)

* Tue Jun 30 2015 wally <wally> 0.9.14-10.mga6
+ Revision: 848457
- add requires for gir pkg to devel pkg

* Sun Dec 14 2014 guillomovitch <guillomovitch> 0.9.14-9.mga5
+ Revision: 803079
- add upstream patch to fix gnome-contact and empathy crash

* Wed Oct 15 2014 umeabot <umeabot> 0.9.14-8.mga5
+ Revision: 740062
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 wally <wally> 0.9.14-7.mga5
+ Revision: 724977
- rebuild with new rpm-mageia-setup to generate requires for .typelib files

* Tue Sep 16 2014 umeabot <umeabot> 0.9.14-6.mga5
+ Revision: 690864
- Mageia 5 Mass Rebuild

* Wed Jul 23 2014 ovitters <ovitters> 0.9.14-5.mga5
+ Revision: 656092
- add upstream patch to fix zeitgeist vala bindings

* Wed Jul 23 2014 ovitters <ovitters> 0.9.14-4.mga5
+ Revision: 656054
- try rebuild for new glib in vala bindings
+ pterjan <pterjan>
- Rebuild for new Python

* Sat Oct 19 2013 umeabot <umeabot> 0.9.14-2.mga4
+ Revision: 528604
- Mageia 4 Mass Rebuild

* Wed Jun 26 2013 dams <dams> 0.9.14-1.mga4
+ Revision: 446693
- new version 0.9.14

* Mon May 27 2013 blino <blino> 0.9.12-1.mga4
+ Revision: 428529
- buildrequire gobject-introspection-1.0
- buildrequire gtk+-3.0 and json-glib-1.0
- buildrequire telepathy-glib
- buildrequire vala-devel
- add lib/gir/devel sub-packages
- package bash-completion for zeitgeist-daemon
- package zeitgeist-datahub
- do not package fts daemon, it is now disabled by default
- 0.9.12

* Mon Jan 14 2013 umeabot <umeabot> 0.9.5-2.mga3
+ Revision: 387665
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 05 2013 dmorgan <dmorgan> 0.9.5-1.mga3
+ Revision: 338916
- New version 0.9.5

* Wed Aug 31 2011 fwang <fwang> 0.8.1.1-1.mga2
+ Revision: 136898
- new version 0.8.1.1

* Sat Mar 26 2011 dmorgan <dmorgan> 0.7.1-1.mga2
+ Revision: 77540
- Fix file list
- Fix package layout
- imported package zeitgeist


* Mon Mar 21 2011 Götz Waschk <waschk@mandriva.org> 0.7.1-1mdv2011.0
+ Revision: 647347
- update to new version 0.7.1

* Tue Jan 18 2011 Götz Waschk <waschk@mandriva.org> 0.7-1
+ Revision: 631604
- new version

* Mon Nov 01 2010 Götz Waschk <waschk@mandriva.org> 0.6-1mdv2011.0
+ Revision: 591549
- new version
- update file list, removing zeitgeist-datahub

  + Michael Scherer <misc@mandriva.org>
    - rebuild for python 2.7

* Fri Sep 10 2010 Götz Waschk <waschk@mandriva.org> 0.5.1-1mdv2011.0
+ Revision: 577054
- update to new version 0.5.1

* Fri Aug 06 2010 Götz Waschk <waschk@mandriva.org> 0.5.0-1mdv2011.0
+ Revision: 566646
- new version
- new URL
- update deps
- update file list

* Sun Jul 11 2010 Götz Waschk <waschk@mandriva.org> 0.3.3.1-1mdv2011.0
+ Revision: 550984
- update to new version 0.3.3.1

* Tue Apr 20 2010 Götz Waschk <waschk@mandriva.org> 0.3.3-1mdv2010.1
+ Revision: 537241
- update to new version 0.3.3

* Wed Jan 20 2010 Götz Waschk <waschk@mandriva.org> 0.3.2-1mdv2010.1
+ Revision: 493954
- update to new version 0.3.2

* Mon Jan 11 2010 Götz Waschk <waschk@mandriva.org> 0.3.1-1mdv2010.1
+ Revision: 489560
- new version

* Tue Dec 01 2009 Götz Waschk <waschk@mandriva.org> 0.3.0-1mdv2010.1
+ Revision: 472447
- new version

* Mon Aug 17 2009 Götz Waschk <waschk@mandriva.org> 0.2.1-1mdv2010.0
+ Revision: 417161
- new version
- update source URL
- update doc list

* Wed Jul 15 2009 Götz Waschk <waschk@mandriva.org> 0.2.0-2mdv2010.0
+ Revision: 396309
- add missing dep on storm
- add docs

* Wed Jul 15 2009 Götz Waschk <waschk@mandriva.org> 0.2.0-1mdv2010.0
+ Revision: 396292
- import zeitgeist


